@@ -97,7 +97,7 @@ expr_template <- function(no.parameters,
           " = ",
           p.value,
           ", ",
-          effsize.text,
+          widehat(effsize.text),
           " = ",
           effsize.estimate,
           ", CI"[conf.level],
@@ -157,7 +157,7 @@ expr_template <- function(no.parameters,
           " = ",
           p.value,
           ", ",
-          effsize.text,
+          widehat(effsize.text),
           " = ",
           effsize.estimate,
           ", CI"[conf.level],
@@ -222,7 +222,7 @@ expr_template <- function(no.parameters,
           " = ",
           p.value,
           ", ",
-          effsize.text,
+          widehat(effsize.text),
           " = ",
           effsize.estimate,
           ", CI"[conf.level],
