@@ -36,7 +36,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          epsilon^2,
+          widehat(epsilon^2),
           " = ",
           "0.21730",
           ", CI"["95%"],
@@ -85,7 +85,7 @@ testthat::test_that(
           " = ",
           "0.155",
           ", ",
-          epsilon^2,
+          widehat(epsilon^2),
           " = ",
           "0.175",
           ", CI"["99%"],
@@ -142,7 +142,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic("W")["Kendall"],
+          widehat(italic("W")["Kendall"]),
           " = ",
           "0.6148",
           ", CI"["99%"],
@@ -190,7 +190,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic("W")["Kendall"],
+          widehat(italic("W")["Kendall"]),
           " = ",
           "0.486",
           ", CI"["90%"],
