@@ -38,7 +38,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          eta["p"]^2,
+          widehat(eta["p"]^2),
           " = ",
           "0.13123",
           ", CI"["95%"],
@@ -99,7 +99,7 @@ testthat::test_that(
           " = ",
           "0.277",
           ", ",
-          eta^2,
+          widehat(eta^2),
           " = ",
           "0.085",
           ", CI"["95%"],
@@ -157,7 +157,7 @@ testthat::test_that(
           " = ",
           "0.1017",
           ", ",
-          omega["p"]^2,
+          widehat(omega["p"]^2),
           " = ",
           "0.1438",
           ", CI"["95%"],
@@ -216,7 +216,7 @@ testthat::test_that(
           " = ",
           "0.0105",
           ", ",
-          eta["p"]^2,
+          widehat(eta["p"]^2),
           " = ",
           "0.1926",
           ", CI"["95%"],
@@ -293,7 +293,7 @@ testthat::test_that(
           " = ",
           "0.1017",
           ", ",
-          eta^2,
+          widehat(eta^2),
           " = ",
           "0.1926",
           ", CI"["95%"],
@@ -326,7 +326,7 @@ testthat::test_that(
           " = ",
           "0.1017",
           ", ",
-          omega^2,
+          widehat(omega^2),
           " = ",
           "0.1438",
           ", CI"["99%"],
@@ -389,7 +389,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          omega^2,
+          widehat(omega^2),
           " = ",
           "0.707",
           ", CI"["99%"],
@@ -449,7 +449,7 @@ testthat::test_that(
           " = ",
           "0.0041",
           ", ",
-          eta["p"]^2,
+          widehat(eta["p"]^2),
           " = ",
           "0.2304",
           ", CI"["99%"],
@@ -500,7 +500,7 @@ testthat::test_that(
           " = ",
           "0.00844",
           ", ",
-          omega^2,
+          widehat(omega^2),
           " = ",
           "0.01701",
           ", CI"["90%"],
@@ -563,7 +563,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          eta["p"]^2,
+          widehat(eta["p"]^2),
           " = ",
           "0.82",
           ", CI"["50%"],
@@ -676,7 +676,7 @@ testthat::test_that(
         " = ",
         "< 0.001",
         ", ",
-        omega^2,
+        widehat(omega^2),
         " = ",
         "0.60",
         ", CI"["95%"],
