@@ -38,7 +38,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic(xi),
+          widehat(italic(xi)),
           " = ",
           "0.56962",
           ", CI"["95%"],
@@ -89,7 +89,7 @@ testthat::test_that(
           " = ",
           "0.7653",
           ", ",
-          italic(xi),
+          widehat(italic(xi)),
           " = ",
           "0.1415",
           ", CI"["99%"],
