@@ -33,7 +33,7 @@ testthat::test_that(
           " = ",
           "0.001",
           ", ",
-          italic(r),
+          widehat(italic(r)),
           " = ",
           "-0.133",
           ", CI"["90%"],
@@ -131,7 +131,7 @@ testthat::test_that(
           " = ",
           "0.00295",
           ", ",
-          italic(r),
+          widehat(italic(r)),
           " = ",
           "-0.75000",
           ", CI"["99%"],
