@@ -34,7 +34,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic("g"),
+          widehat(italic("g")),
           " = ",
           "-0.57970",
           ", CI"["95%"],
@@ -81,7 +81,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic("g"),
+          widehat(italic("g")),
           " = ",
           "-0.580",
           ", CI"["99%"],
@@ -130,7 +130,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic("d"),
+          widehat(italic("d")),
           " = ",
           "-0.5800",
           ", CI"["90%"],
@@ -179,7 +179,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic("d"),
+          widehat(italic("d")),
           " = ",
           "-0.58",
           ", CI"["50%"],
@@ -236,7 +236,7 @@ testthat::test_that(
           " = ",
           "0.3227",
           ", ",
-          italic("r"),
+          widehat(italic("r")),
           " = ",
           "-0.1282",
           ", CI"["95%"],
