@@ -38,7 +38,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic(xi),
+          widehat(italic(xi)),
           " = ",
           "0.9265",
           ", CI"["90%"],
@@ -114,7 +114,7 @@ testthat::test_that(
         " = ",
         "0.002",
         ", ",
-        italic(xi),
+        widehat(italic(xi)),
         " = ",
         "0.273",
         ", CI"["99%"],
@@ -171,7 +171,7 @@ testthat::test_that(
           " = ",
           "< 0.001",
           ", ",
-          italic(xi),
+          widehat(italic(xi)),
           " = ",
           "0.812",
           ", CI"["99%"],
