@@ -21,7 +21,7 @@ testthat::test_that(
           " = ",
           "0.013",
           ", ",
-          italic("r"),
+          widehat(italic("r")),
           " = ",
           "0.52",
           ", CI"["99%"],
@@ -83,7 +83,7 @@ testthat::test_that(
           " = ",
           "0.013",
           ", ",
-          italic(V),
+          widehat(italic(V)),
           " = ",
           "0.52",
           ", CI"["99%"],
@@ -164,7 +164,7 @@ testthat::test_that(
           " = ",
           "0.107",
           ", ",
-          omega["p"]^2,
+          widehat(omega["p"]^2),
           " = ",
           "0.00",
           ", CI"["95%"],
